from nba_stats_tracking.models.boxscore.boxscore import BoxscoreResults
from nba_stats_tracking.models.boxscore.request import BoxscoreRequestParameters

__all__ = [
    "BoxscoreRequestParameters",
    "BoxscoreResults",
]
